@@ -39,7 +39,7 @@ echo "1) ecm_qt_declare_logging_category(<file>_SRCS HEADER $debugnamefile.h IDE
 echo "2) Add #include \"$debugnamefile.h\" to each file which was changed if it is not there yet"
 echo "3) Add include(ECMQtDeclareLoggingCategory) to CMakeLists.txt"
 echo "4) Add '$newlogname <description> IDENTIFIER [$newcategoryname]' to <name>.categories"
-echo "4) install( FILES <name>.categories DESTINATION \${KDE_INSTALL_CONFDIR} ) to CMakeLists.txt"
+echo "4) install( FILES <name>.categories DESTINATION \${KDE_INSTALL_LOGGINGCATEGORIESDIR} ) to CMakeLists.txt"
 echo "5) Verify that it compiles :)"
 echo "6) If you find bugs fix them please me"
 
